==> nettle_3.7.3.orig.tar.gz: nettle-3.7.3/hmac-md5.c <==
/* hmac-md5.c

   HMAC-MD5 message authentication code.

   Copyright (C) 2002 Niels Möller

   This file is part of GNU Nettle.

   GNU Nettle is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at your
       option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at your
       option) any later version.

   or both in parallel, as here.

   GNU Nettle is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received copies of the GNU General Public License and
   the GNU Lesser General Public License along with this program.  If
   not, see http://www.gnu.org/licenses/.
*/

#if HAVE_CONFIG_H
# include "config.h"
#endif

#include "hmac.h"

void
hmac_md5_set_key(struct hmac_md5_ctx *ctx,
		 size_t key_length, const uint8_t *key)
{
  HMAC_SET_KEY(ctx, &nettle_md5, key_length, key);
}

void
hmac_md5_update(struct hmac_md5_ctx *ctx,
		size_t length, const uint8_t *data)
{
  md5_update(&ctx->state, length, data);
}

void
hmac_md5_digest(struct hmac_md5_ctx *ctx,
		size_t length, uint8_t *digest)
{
  HMAC_DIGEST(ctx, &nettle_md5, length, digest);
}

==> nettle-4.0.tar.gz: nettle-4.0/hmac-md5.c <==
/* hmac-md5.c

   HMAC-MD5 message authentication code.

   Copyright (C) 2002, 2025 Niels Möller

   This file is part of GNU Nettle.

   GNU Nettle is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at your
       option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at your
       option) any later version.

   or both in parallel, as here.

   GNU Nettle is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received copies of the GNU General Public License and
   the GNU Lesser General Public License along with this program.  If
   not, see http://www.gnu.org/licenses/.
*/

#if HAVE_CONFIG_H
# include "config.h"
#endif

#include "hmac.h"
#include "hmac-internal.h"

void
hmac_md5_set_key(struct hmac_md5_ctx *ctx,
		 size_t key_length, const uint8_t *key)
{
  _nettle_hmac_set_key (sizeof(ctx->outer), ctx->outer, ctx->inner, &ctx->state,
			ctx->state.block, &nettle_md5, key_length, key);
}

void
hmac_md5_update(struct hmac_md5_ctx *ctx,
		size_t length, const uint8_t *data)
{
  md5_update(&ctx->state, length, data);
}

void
hmac_md5_digest(struct hmac_md5_ctx *ctx,
		uint8_t *digest)
{
  _NETTLE_HMAC_DIGEST (ctx->outer, ctx->inner, &ctx->state, md5_digest,
		       MD5_DIGEST_SIZE, digest);
}
